@@ -1,4 +1,4 @@
-from sinaspider.helper import config
+from sinaspider.helper import get_config
 from sinaspider.weibo import Weibo
 from sinaspider.user import User, Owner
 from sinaspider.user_config import UserConfig
